import System from 'corpjs-system'
import Endpoints from 'corpjs-endpoints'
import mongodb = require('mongodb')

export function MongoDb(alias: string = 'localhost:27017'): System.Component {

  let db: mongodb.Db

  return {
    
    async start({config, endpoints}: { config: MongoDb.Config, endpoints: Endpoints.CorpjsEndpoints }, _, stop): Promise<mongodb.Db> {
      const address = endpoints.getServiceAddress(alias)
      const authUri = config.user && config.password ? `${config.user}:${config.password}@` : ''
      const url = `mongodb://${authUri}${address}/${config.db}`
      db = await mongodb.MongoClient.connect(url, config.options)
      db.on('error', stop)
      return db
    },

    async stop() {
      if (db) db.close()
    }
  }

}

export namespace MongoDb {

  export interface Config {
    db: string
    user?: string
    password?: string
    options?: mongodb.MongoClientOptions
  }

}

export default MongoDb