import 'mocha'
import * as assert from 'assert'
import System from 'corpjs-system'
import Endpoints from 'corpjs-endpoints'
import MongoDb from '../src'

xdescribe('corpjs-mongodb', () => {

  let system

  beforeEach(async () => {
    if (system) await system.stop()
  })

  it('should get connection error', done => {
    system = createSystem()
    system.start().then(({mongo}) => {
      done(new Error("Connection created but shouldn't"))
    }).catch(err => {
      assert.ok(/failed to connect/.test(err.message))
      done()
    })
  })

})

function createSystem(): System {
  return new System({ exitOnError: false })
    .add('config', Config())
    .add('endpoints', Endpoints()).dependsOn('config')
    .add('mongo', MongoDb()).dependsOn('endpoints', { component: 'config', source: 'mongodb', as: 'config' })
}

function Config() {
  return {
    async start() {
      return {
        systemEndpoints: 'test_src/endpoints.json',
        mongodb: {
          db: 'test'
        }
      }
    }
  }
}